Crate kcr_keycloak_k8s_reddec_net

Crate kcr_keycloak_k8s_reddec_net 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the keycloak.k8s.reddec.net group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

keycloak.k8s.reddec.net/v1alpha1

  • KeycloakClient

Modules

v1alpha1