This crate contains kube-rs compatible bindings for Kubernetes custom resources for the keycloak.k8s.reddec.net group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
keycloak.k8s.reddec.net/v1alpha1
KeycloakClient